==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/INVOICELINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INVOICELINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INVOICELINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICELINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVOICELINEID_Type", propOrder = {
    "invoiceid",
    "invoicelinenum"
})
public class INVOICELINEID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "INVOICELINENUM")
    protected long invoicelinenum;

    /**
     * Obtient la valeur de la propriété invoiceid.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Définit la valeur de la propriété invoiceid.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Obtient la valeur de la propriété invoicelinenum.
     * 
     */
    public long getINVOICELINENUM() {
        return invoicelinenum;
    }

    /**
     * Définit la valeur de la propriété invoicelinenum.
     * 
     */
    public void setINVOICELINENUM(long value) {
        this.invoicelinenum = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/INVOICELINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVOICELINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INVOICELINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICELINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVOICELINEID_Type", propOrder = {
    "invoiceid",
    "invoicelinenum"
})
public class INVOICELINEID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "INVOICELINENUM")
    protected long invoicelinenum;

    /**
     * Gets the value of the invoiceid property.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Sets the value of the invoiceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Gets the value of the invoicelinenum property.
     * 
     */
    public long getINVOICELINENUM() {
        return invoicelinenum;
    }

    /**
     * Sets the value of the invoicelinenum property.
     * 
     */
    public void setINVOICELINENUM(long value) {
        this.invoicelinenum = value;
    }

}
